summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xupdate_jdn.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/update_jdn.sh b/update_jdn.sh
index 9dd6a3f8..dbc50a69 100755
--- a/update_jdn.sh
+++ b/update_jdn.sh
@@ -263,10 +263,11 @@ if [ -f /etc/debian_version ] ; then
fi
#
# deploy package configuration in /etc
#
cd $BASEDIR
sudo cp --preserve=mode,timestamps -r hosts/$HOSTNAME/etc/* /etc
+sudo cp --preserve=mode,timestamps -r hosts/$HOSTNAME/usr/local/* /usr/local/
#
# more configuration than a simple cp can do
@@ -263,10 +263,11 @@ if [ -f /etc/debian_version ] ; then
fi
#
-# deploy package configuration in /etc
+# deploy package configuration in /etc and /usr/local/
#
cd $BASEDIR